@@ -11,7 +11,7 @@ use lib 'lib';
 use bytes;
 use Carp;
 use Time::HiRes     qw( gettimeofday );
-use Redis;
+use Redis '1.976';
 use List::Util      qw( min sum );
 use Getopt::Long    qw( GetOptions );
 use Data::Dumper;
@@ -338,7 +338,7 @@ $big_data_threshold = 0 if $find_optimal;
 do
 {
     $redis->flushall if $dump;
-    $coll = Redis::CappedCollection->new(
+    $coll = Redis::CappedCollection->create(
         $redis,
         name            => $coll_name,
         $receive ? () : (
